@@ -2,13 +2,10 @@
 
 void hier()
 {
-  h(auto_home,-1,-1,02755);
-  d(auto_home,"etc",-1,-1,02755);
-  d(auto_home,"etc/dnscache",-1,-1,02755);
-  d(auto_home,"bin",-1,-1,02755);
+  c("/","etc","dnsroots.global",-1,-1,0644);
 
-  c(auto_home,"etc/dnscache","VERSION",-1,-1,0644);
-  c(auto_home,"etc/dnscache","@",-1,-1,0644);
+  h(auto_home,-1,-1,02755);
+  d(auto_home,"bin",-1,-1,02755);
 
   c(auto_home,"bin","dnscache-conf",-1,-1,0755);
   c(auto_home,"bin","tinydns-conf",-1,-1,0755);
